#!/usr/bin/env python
import sys
import numpy as np
import scipy.constants as const
import matplotlib.pyplot as plt 

meters = 1.0
millimeters = const.milli*meters
microns = const.micro*meters
seconds = 1.0
femtoseconds = const.femto*seconds

def gas_profile(x):
    gas_factor = -1.0
    gas_power  = 4.0
    gas_center_left = 1.0e-4
    gas_center_right = 3.9e-3
    gas_sigma_left =  0.5e-4
    gas_sigma_right = 0.5e-4

    exponent = 0.0
    if x < gas_center_left:
        exponent = np.abs((x - gas_center_left) / gas_sigma_left)
    elif x >= gas_center_right:
        exponent = np.abs((x - gas_center_right) / gas_sigma_right)
    density = np.exp(gas_factor * exponent**gas_power)
    return density


sim_x, sim_ne = np.loadtxt('check_data', unpack=True)
x = np.linspace(0.0, 5.0, 1024) * millimeters

fig = plt.figure()
ax1 = fig.add_subplot(1,1,1)
ax1.plot(x/millimeters,map(gas_profile,x))
ax1.plot(sim_x/millimeters, sim_ne/1.86e24, 'ro--')
ax1.set_xlabel('y, mm')
ax1.set_ylabel('ne, a.u.')

plt.show()
